@@ -401,6 +401,9 @@ RESOURCENOTFOUND_FLOWAPPROVER = 'ResourceNotFound.FlowApprover'
 # 签署人信息不存在，请检查后重试。
 RESOURCENOTFOUND_FLOWAPPROVERS = 'ResourceNotFound.FlowApprovers'
 
+# 合同组不存在。
+RESOURCENOTFOUND_FLOWGROUP = 'ResourceNotFound.FlowGroup'
+
 # 机构不存在。
 RESOURCENOTFOUND_ORGANIZATION = 'ResourceNotFound.Organization'
 
