@@ -14,6 +14,12 @@
 # limitations under the License.
 
 
+# 服务器繁忙,请稍后再试。
+FAILEDOPERATION_DEFAULTINTERNALERROR = 'FailedOperation.DefaultInternalError'
+
+# 删除应用失败。
+FAILEDOPERATION_DELETESERVICEERROR = 'FailedOperation.DeleteServiceError'
+
 # 请求响应超时。
 INTERNALERROR_ACTIONREADTIMEOUT = 'InternalError.ActionReadTimeout'
 
@@ -59,6 +65,9 @@ INTERNALERROR_DESCRIBECONFIGDATALISTERROR = 'InternalError.DescribeConfigDataLis
 # 查询 ingress 失败。
 INTERNALERROR_DESCRIBEINGRESSERROR = 'InternalError.DescribeIngressError'
 
+# 查询 ingress 列表失败。
+INTERNALERROR_DESCRIBEINGRESSLISTERROR = 'InternalError.DescribeIngressListError'
+
 # 查询 LogConfig 错误。
 INTERNALERROR_DESCRIBELOGCONFIGERROR = 'InternalError.DescribeLogConfigError'
 
@@ -161,6 +170,9 @@ INVALIDPARAMETERVALUE_HPAMETRICSINVALID = 'InvalidParameterValue.HpaMetricsInval
 # 弹性伸缩最小值/最大值不合法。
 INVALIDPARAMETERVALUE_HPAMINMAXINVALID = 'InvalidParameterValue.HpaMinMaxInvalid'
 
+# 弹性伸缩阈值不合法。
+INVALIDPARAMETERVALUE_HPATHRESHOLDINVALID = 'InvalidParameterValue.HpaThresholdInvalid'
+
 # 访问配置重定向需要启用 HTTPS。
 INVALIDPARAMETERVALUE_INGRESSREWRITEREQUIREDHTTPSENABLE = 'InvalidParameterValue.IngressRewriteRequiredHttpsEnable'
 
@@ -269,6 +281,12 @@ INVALIDPARAMETERVALUE_VERSIONLOWERCASE = 'InvalidParameterValue.VersionLowerCase
 # 版本的路由流量不为0。
 INVALIDPARAMETERVALUE_VERSIONROUTERATENOTZERO = 'InvalidParameterValue.VersionRouteRateNotZero'
 
+# vpc错误, 与环境vpc不一致。
+INVALIDPARAMETERVALUE_VPCINVALID = 'InvalidParameterValue.VpcInvalid'
+
+# 弹性规则名称不能为空。
+MISSINGPARAMETER_AUTOSCALERNAMENULL = 'MissingParameter.AutoScalerNameNull'
+
 # 部署方式不能为空。
 MISSINGPARAMETER_DEPLOYMODENULL = 'MissingParameter.DeployModeNull'
 
